static const unsigned char fontdata_preloaded[] = {
    144,  15,  85,  85, 128,   0,   0,   1,
    128,   0,   0,   1, 128,   0,   0,   1,
    201, 158,  90,  81, 234,  80,  74,  81,
    128,   0,   0,   1, 128,   0,   0,   1,
    170, 170, 144,  15,  85,  85, 128,   0,
      0,   1, 128,   0,   0,   1, 128,   0,
    113, 147, 138,  82,  50,  95, 194,  82,
     57, 147, 128,   0,   0,   1, 128,   0,
      0,   1, 170, 170, 144,  15,  85,  85,
    128,   0,   0,   1, 128,   0,   0,   1,
    128,   0, 113,  37, 137,  36,  49,  25,
    193,  36,  59, 165, 128,   0,   0,   1,
    128,   0,   0,   1, 170, 170, 144,  15,
     85,  85, 128,   0,   0,   1, 128,   0,
      0,   1, 128,   0, 121,  37, 193,  36,
    121,  25, 193,  36, 123, 165, 128,   0,
      0,   1, 128,   0,   0,   1, 170, 170,
    144,  15,  85,  85, 128,   0,   0,   1,
    128,   0,   0,   1, 128,   0, 121, 137,
    194,  72, 122,  73, 194,  72, 121, 191,
    128,   0,   0,   1, 128,   0,   0,   1,
    170, 170, 144,  15,  85,  85, 128,   0,
      0,   1, 128,   0,   0,   1, 128,   0,
    122,  79, 194, 214, 123,  83, 194,  82,
    122,  77, 128,   0,   0,   1, 128,   0,
      0,   1, 170, 170, 144,  15,  85,  85,
    128,   0,   0,   1, 128,   0,   0,   1,
    128,   0,  73, 165, 202,  40, 122,  49,
    202,  40,  49, 165, 128,   0,   0,   1,
    128,   0,   0,   1, 170, 170, 144,  15,
     85,  85, 128,   0,   0,   1, 128,   0,
      0,   1, 128,   0, 115, 223, 202,  16,
    115, 209, 202,  16, 115, 209, 128,   0,
      0,   1, 128,   0,   0,   1, 170, 170,
    144,  15,  85,  85, 128,   0,   0,   1,
    128,   0,   0,   1, 128,   0,  30, 113,
    145,   8,  30,  49, 145,  64,  30,  57,
    128,   0,   0,   1, 128,   0,   0,   1,
    170, 170, 144,  15,  85,  85, 128,   0,
      0,   1, 128,   0,   0,   1, 128,   0,
     34,  33, 162,  32,  62,  33, 162,  32,
     34, 249, 128,   0,   0,   1, 128,   0,
      0,   1, 170, 170, 144,  15,  85,  85,
    128,   0,   0,   1, 128,   0,   0,   1,
    128,   0,  62, 129, 160, 128,  32, 249,
    160, 128,  32, 249, 128,   0,   0,   1,
    128,   0,   0,   1, 170, 170, 144,  15,
     85,  85, 128,   0,   0,   1, 128,   0,
      0,   1, 128,   0,   8,  33, 148,  32,
     34,  33, 162,  32,  34, 249, 128,   0,
      0,   1, 128,   0,   0,   1, 170, 170,
    144,  15,  85,  85, 128,   0,   0,   1,
    128,   0,   0,   1, 128,   0,  32, 129,
    160, 128,  62, 249, 160, 128,  62, 249,
    128,   0,   0,   1, 128,   0,   0,   1,
    170, 170, 144,  15,  85,  85, 128,   0,
      0,   1, 128,   0,   0,   1, 128,   0,
     30, 137, 160, 144,  32, 241, 160, 136,
     30, 241, 128,   0,   0,   1, 128,   0,
      0,   1, 170, 170, 144,  15,  85,  85,
    128,   0,   0,   1, 128,   0,   0,   1,
    128,   0,  60, 113, 130, 136,  28, 137,
    160, 136,  30, 113, 128,   0,   0,   1,
    128,   0,   0,   1, 170, 170, 144,  15,
     85,  85, 128,   0,   0,   1, 128,   0,
      0,   1, 128,   0,  60, 249, 130,  32,
     28,  33, 160,  32,  30, 249, 128,   0,
      0,   1, 128,   0,   0,   1, 170, 170,
    144,  15,  85,  85, 128,   0,   0,   1,
    128,   0,   0,   1, 128,   0,  57, 221,
    165,  16,  37,  29, 165,  16,  57,  29,
    128,   0,   0,   1, 128,   0,   0,   1,
    170, 170, 144,  15,  85,  85, 128,   0,
      0,   1, 128,   0,   0,   1, 128,   0,
    113, 157, 202,   8,  74,   9, 202,  24,
    113, 137, 128,   0,   0,   1, 128,   0,
      0,   1, 170, 170, 144,  15,  85,  85,
    128,   0,   0,   1, 128,   0,   0,   1,
    128,   0, 113, 157, 202,  16,  74,   9,
    202,   4, 113, 153, 128,   0,   0,   1,
    128,   0,   0,   1, 170, 170, 144,  15,
     85,  85, 128,   0,   0,   1, 128,   0,
      0,   1, 128,   0, 113, 153, 202,   4,
     74,  25, 202,   4, 113, 153, 128,   0,
      0,   1, 128,   0,   0,   1, 170, 170,
    144,  15,  85,  85, 128,   0,   0,   1,
    128,   0,   0,   1, 128,   0, 113, 133,
    202,  28,  74,  21, 202,  12, 113, 133,
    128,   0,   0,   1, 128,   0,   0,   1,
    170, 170, 144,  15,  85,  85, 128,   0,
      0,   1, 128,   0,   0,   1, 128,   0,
     74,  83, 219, 212, 106,  89, 234,  84,
     73, 147, 128,   0,   0,   1, 128,   0,
      0,   1, 170, 170, 144,  15,  85,  85,
    128,   0,   0,   1, 128,   0,   0,   1,
    128,   0, 113,  19, 137,  18,  49,  23,
    194, 154,  52,  83, 128,   0,   0,   1,
    128,   0,   0,   1, 170, 170, 144,  15,
     85,  85, 128,   0,   0,   1, 128,   0,
      0,   1, 128,   0, 121,  57, 193,  36,
    121,  57, 193,  36, 123, 185, 128,   0,
      0,   1, 128,   0,   0,   1, 170, 170,
    144,  15,  85,  85, 128,   0,   0,   1,
    128,   0,   0,   1, 128,   0,  52, 165,
    196, 164,  71, 173, 196, 180,  51,  37,
    128,   0,   0,   1, 128,   0,   0,   1,
    170, 170, 144,  15,  85,  85, 128,   0,
      0,   1, 128,   0,   0,   1, 128,   0,
     62, 137, 160, 136,  62, 169, 160, 216,
     62, 137, 128,   0,   0,   1, 128,   0,
      0,   1, 170, 170, 144,  15,  85,  85,
    128,   0,   0,   1, 128,   0,   0,   1,
    128,   0, 113, 157, 138,  82,  50,  93,
    194,  82,  58,  93, 128,   0,   0,   1,
    128,   0,   0,   1, 170, 170, 144,  15,
     85,  85, 128,   0,   0,   1, 128,   0,
      0,   1, 128,   0, 123, 143, 192,  80,
    121, 145, 194,  16, 121, 207, 128,   0,
      0,   1, 128,   0,   0,   1, 170, 170,
    144,  15,  85,  85, 128,   0,   0,   1,
    128,   0,   0,   1, 128,   0,  16, 225,
    144,  16,  30,  97, 144, 128,  30, 113,
    128,   0,   0,   1, 128,   0,   0,   1,
    170, 170, 144,  15,  85,  85, 128,   0,
      0,   1, 128,   0,   0,   1, 128,   0,
     14, 225, 146,  16,  22,  97, 144, 128,
     14, 113, 128,   0,   0,   1, 128,   0,
      0,   1, 170, 170, 144,  15,  85,  85,
    128,   0,   0,   1, 128,   0,   0,   1,
    128,   0,  18, 225, 148,  16,  28,  97,
    146, 128,  28, 113, 128,   0,   0,   1,
    128,   0,   0,   1, 170, 170, 144,  15,
     85,  85, 128,   0,   0,   1, 128,   0,
      0,   1, 128,   0,  12, 225, 146,  16,
     18,  97, 146, 128,  18, 113, 128,   0,
      0,   1, 128,   0,   0,   1, 170, 170,
      4,  65,  41, 128, 128,   0, 128, 128,
    128, 128, 128, 128, 128,  69, 163, 136,
    136, 136, 136,  70,  41, 144, 144, 144,
    252,  72,  72, 252,  36,  36,  36,  71,
     41,  16, 124, 146,  18,  28, 112, 144,
    146, 124,  16,  71,  41, 140,  82,  82,
     44,  16,  16, 104, 148, 148,  98,  71,
     41, 114, 140, 132, 138,  82,  48,  40,
     68,  68,  56,  65, 163, 128, 128, 128,
    128,  67,  27,  32,  64,  64, 128, 128,
    128, 128, 128, 128,  64,  64,  32,  67,
     27, 128,  64,  64,  32,  32,  32,  32,
     32,  32,  64,  64, 128,  71,  54,  16,
    146,  84,  56,  84, 146,  16,  71,  54,
     16,  16,  16, 254,  16,  16,  16,  66,
      3, 128,  64,  64, 192,  68,  96, 240,
     66,  33, 192, 192,  70,  41, 128, 128,
     64,  32,  32,  16,  16,   8,   4,   4,
     70,  41,  48,  72, 132, 196, 164, 148,
    140, 132,  72,  48,  69,  41, 248,  32,
     32,  32,  32,  32,  32, 160,  96,  32,
     70,  41, 252, 128, 128,  64,  32,  24,
      4, 132, 132, 120,  70,  41, 120, 132,
    132,   4,   4,  56,   4, 132, 132, 120,
     70,  41,   8,   8,   8, 252, 136, 136,
     72,  40,  24,   8,  70,  41, 120, 132,
      4,   4,   4, 248, 128, 128, 128, 252,
     70,  41, 120, 132, 132, 132, 132, 248,
    128, 128,  64,  56,  70,  41,  16,  16,
     16,  16,   8,   8,   8,   4,   4, 252,
     70,  41, 120, 132, 132, 132, 132, 120,
    132, 132, 132, 120,  70,  41, 112,   8,
      4,   4,   4, 124, 132, 132, 132, 120,
     66,  54, 192, 192,   0,   0,   0, 192,
    192,  66,  24, 128,  64,  64, 192,   0,
      0,   0, 192, 192,  69,  40,   8,  16,
     32,  64, 128,  64,  32,  16,   8,  70,
     68, 252,   0,   0,   0, 252,  69,  40,
    128,  64,  32,  16,   8,  16,  32,  64,
    128,  70,  41,  16,  16,   0,  16,  16,
      8,   4, 132, 132, 120,  70,  41,  60,
     64, 156, 164, 164, 164, 172, 148,  68,
     56,  70,  41, 132, 132, 132, 132, 252,
    132, 132,  72,  72,  48,  70,  41, 248,
    132, 132, 132, 132, 248, 132, 132, 132,
    248,  70,  41, 120, 132, 132, 128, 128,
    128, 128, 132, 132, 120,  70,  41, 240,
    136, 132, 132, 132, 132, 132, 132, 136,
    240,  70,  41, 252, 128, 128, 128, 128,
    248, 128, 128, 128, 252,  70,  41, 128,
    128, 128, 128, 128, 248, 128, 128, 128,
    252,  70,  41, 116, 140, 132, 132, 156,
    128, 128, 132, 132, 120,  70,  41, 132,
    132, 132, 132, 132, 252, 132, 132, 132,
    132,  69,  41, 248,  32,  32,  32,  32,
     32,  32,  32,  32, 248,  71,  41, 112,
    136, 136,   8,   8,   8,   8,   8,   8,
     62,  70,  41, 132, 136, 144, 160, 192,
    192, 160, 144, 136, 132,  70,  41, 252,
    128, 128, 128, 128, 128, 128, 128, 128,
    128,  70,  41, 132, 132, 132, 132, 180,
    180, 204, 204, 132, 132,  70,  41, 132,
    140, 140, 148, 148, 164, 164, 196, 196,
    132,  70,  41, 120, 132, 132, 132, 132,
    132, 132, 132, 132, 120,  70,  41, 128,
    128, 128, 128, 128, 248, 132, 132, 132,
    248,  71,  26,   6, 120, 204, 180, 132,
    132, 132, 132, 132, 132, 120,  70,  41,
    132, 132, 136, 136, 144, 248, 132, 132,
    132, 248,  70,  41, 120, 132, 132,   4,
     24,  96, 128, 132, 132, 120,  71,  41,
     16,  16,  16,  16,  16,  16,  16,  16,
     16, 254,  70,  41, 120, 132, 132, 132,
    132, 132, 132, 132, 132, 132,  71,  41,
     16,  16,  40,  40,  68,  68,  68, 130,
    130, 130,  70,  41, 132, 132, 204, 204,
    180, 180, 132, 132, 132, 132,  70,  41,
    132, 132,  72,  72,  48,  48,  72,  72,
    132, 132,  71,  41,  16,  16,  16,  16,
     16,  40,  68,  68, 130, 130,  70,  41,
    252, 128, 128,  64,  32,  16,   8,   4,
      4, 252,  67,  27, 224, 128, 128, 128,
    128, 128, 128, 128, 128, 128, 128, 224,
     70,  41,   4,   4,   8,  16,  16,  32,
     32,  64, 128, 128,  67,  27, 224,  32,
     32,  32,  32,  32,  32,  32,  32,  32,
     32, 224,  70, 178, 132,  72,  48,  71,
     16, 254,  67, 194,  32,  64, 128,  70,
     39, 116, 140, 132, 132, 124,   4, 132,
    120,  70,  42, 184, 196, 132, 132, 132,
    132, 196, 184, 128, 128, 128,  70,  39,
    120, 132, 128, 128, 128, 128, 132, 120,
     70,  42, 116, 140, 132, 132, 132, 132,
    140, 116,   4,   4,   4,  70,  39, 120,
    132, 128, 128, 252, 132, 132, 120,  69,
     42,  32,  32,  32,  32,  32,  32, 248,
     32,  32,  32,  24,  70,  10, 120, 132,
    132, 120,  64, 112, 136, 136, 136, 116,
      4,  70,  42, 132, 132, 132, 132, 132,
    132, 196, 184, 128, 128, 128,  69,  42,
    248,  32,  32,  32,  32,  32,  32,  96,
      0,  32,  32,  69,  12,  96, 144,   8,
      8,   8,   8,   8,   8,   8,  24,   0,
      8,   8,  70,  42, 132, 136, 144, 160,
    192, 160, 144, 136, 128, 128, 128,  69,
     42, 248,  32,  32,  32,  32,  32,  32,
     32,  32,  32,  96,  71,  39, 146, 146,
    146, 146, 146, 146, 146, 236,  70,  39,
    132, 132, 132, 132, 132, 132, 196, 184,
     70,  39, 120, 132, 132, 132, 132, 132,
    132, 120,  70,   9, 128, 128, 184, 196,
    132, 132, 132, 132, 196, 184,  70,   9,
      4,   4, 116, 140, 132, 132, 132, 132,
    140, 116,  70,  39, 128, 128, 128, 128,
    128, 132, 196, 184,  70,  39, 120, 132,
      4,  24,  96, 128, 132, 120,  69,  41,
     24,  32,  32,  32,  32,  32, 248,  32,
     32,  32,  70,  39, 116, 140, 132, 132,
    132, 132, 132, 132,  70,  39,  48,  48,
     72,  72,  72, 132, 132, 132,  71,  39,
    108, 146, 146, 146, 146, 146, 146, 130,
     70,  39, 132, 132,  72,  48,  48,  72,
    132, 132,  70,   9, 120,   4,   4,  52,
     76, 132, 132, 132, 132, 132,  70,  39,
    252, 128,  64,  32,  16,   8,   4, 252,
     68,  12,  48,  64,  64,  32,  32,  64,
    128,  64,  32,  32,  64,  64,  48,  65,
     13, 128, 128, 128, 128, 128, 128, 128,
    128, 128, 128, 128, 128, 128, 128,  68,
     12, 192,  32,  32,  64,  64,  32,  16,
     32,  64,  64,  32,  32, 192,  71, 162,
    140, 146,  98, 144,  15,  85,  85, 128,
      0,   0,   1, 128,   0,   0,   1, 128,
      0, 115, 223, 202,  16,  75, 209, 202,
     16, 115, 209, 128,   0,   0,   1, 128,
      0,   0,   1, 170, 170, 144,  15,  85,
     85, 128,   0,   0,   1, 128,   0,   0,
      1, 128,   0,  66,  93, 194,  82, 115,
    211, 202,  82, 113, 157, 128,   0,   0,
      1, 128,   0,   0,   1, 170, 170, 144,
     15,  85,  85, 128,   0,   0,   1, 128,
      0,   0,   1, 128,   0,  73, 145, 202,
     80, 122,  93, 202,  82,  73, 157, 128,
      0,   0,   1, 128,   0,   0,   1, 170,
    170, 144,  15,  85,  85, 128,   0,   0,
      1, 128,   0,   0,   1, 128,   0, 114,
     19, 202,  18, 115, 159, 202,  82, 115,
    147, 128,   0,   0,   1, 128,   0,   0,
      1, 170, 170, 144,  15,  85,  85, 128,
      0,   0,   1, 128,   0,   0,   1, 128,
      0,  75, 147, 202,  82,  91, 159, 234,
     82,  75, 147, 128,   0,   0,   1, 128,
      0,   0,   1, 170, 170, 144,  15,  85,
     85, 128,   0,   0,   1, 128,   0,   0,
      1, 128,   0, 116, 185, 164, 164,  37,
    165, 166, 164, 116, 185, 128,   0,   0,
      1, 128,   0,   0,   1, 170, 170, 144,
     15,  85,  85, 128,   0,   0,   1, 128,
      0,   0,   1, 128,   0,  75, 223, 202,
     16,  91, 209, 234,  16,  75, 209, 128,
      0,   0,   1, 128,   0,   0,   1, 170,
    170, 144,  15,  85,  85, 128,   0,   0,
      1, 128,   0,   0,   1, 128,   0, 115,
    147, 136,  82,  49, 159, 194,  18,  57,
    205, 128,   0,   0,   1, 128,   0,   0,
      1, 170, 170, 144,  15,  85,  85, 128,
      0,   0,   1, 128,   0,   0,   1, 128,
      0, 123, 147, 192,  82, 121, 159, 194,
     18, 121, 205, 128,   0,   0,   1, 128,
      0,   0,   1, 170, 170, 144,  15,  85,
     85, 128,   0,   0,   1, 128,   0,   0,
      1, 128,   0,  73,  57, 201,   4, 121,
     25, 201,  32,  75, 157, 128,   0,   0,
      1, 128,   0,   0,   1, 170, 170, 144,
     15,  85,  85, 128,   0,   0,   1, 128,
      0,   0,   1, 128,   0,  36, 153, 164,
    132,  60, 133, 164, 132,  37, 221, 128,
      0,   0,   1, 128,   0,   0,   1, 170,
    170, 144,  15,  85,  85, 128,   0,   0,
      1, 128,   0,   0,   1, 128,   0,  16,
    153, 168, 132,  68, 137, 196, 144,  69,
    205, 128,   0,   0,   1, 128,   0,   0,
      1, 170, 170, 144,  15,  85,  85, 128,
      0,   0,   1, 128,   0,   0,   1, 128,
      0,  67, 221, 194,  18, 114,  19, 202,
     18, 114,  29, 128,   0,   0,   1, 128,
      0,   0,   1, 170, 170, 144,  15,  85,
     85, 128,   0,   0,   1, 128,   0,   0,
      1, 128,   0,  67, 205, 194,  18, 114,
     19, 202,  18, 114,  19, 128,   0,   0,
      1, 128,   0,   0,   1, 170, 170, 144,
     15,  85,  85, 128,   0,   0,   1, 128,
      0,   0,   1, 128,   0,   9,  33, 138,
     32,  14,  33, 137,  32,  14,  33, 128,
      0,   0,   1, 128,   0,   0,   1, 170,
    170, 144,  15,  85,  85, 128,   0,   0,
      1, 128,   0,   0,   1, 128,   0, 115,
    159, 136,  80,  49, 141, 194,   2,  57,
    221, 128,   0,   0,   1, 128,   0,   0,
      1, 170, 170, 144,  15,  85,  85, 128,
      0,   0,   1, 128,   0,   0,   1, 128,
      0, 115, 157, 136,  66,  49, 141, 194,
      2,  57, 221, 128,   0,   0,   1, 128,
      0,   0,   1, 170, 170, 144,  15,  85,
     85, 128,   0,   0,   1, 128,   0,   0,
      1, 128,   0, 113, 221, 202,   2,  74,
     13, 202,  16, 113, 207, 128,   0,   0,
      1, 128,   0,   0,   1, 170, 170, 144,
     15,  85,  85, 128,   0,   0,   1, 128,
      0,   0,   1, 128,   0,  65, 143, 194,
     68, 114,  69, 202,  76, 114,  69, 128,
      0,   0,   1, 128,   0,   0,   1, 170,
    170, 144,  15,  85,  85, 128,   0,   0,
      1, 128,   0,   0,   1, 128,   0,  65,
    159, 194,  80, 114,  77, 202,  66, 114,
     93, 128,   0,   0,   1, 128,   0,   0,
      1, 170, 170, 144,  15,  85,  85, 128,
      0,   0,   1, 128,   0,   0,   1, 128,
      0, 113,  57, 137,   4,  49,  25, 193,
     32,  59, 157, 128,   0,   0,   1, 128,
      0,   0,   1, 170, 170, 144,  15,  85,
     85, 128,   0,   0,   1, 128,   0,   0,
      1, 128,   0,  57, 211, 194,  18,  66,
     31, 194,  18,  57, 211, 128,   0,   0,
      1, 128,   0,   0,   1, 170, 170, 144,
     15,  85,  85, 128,   0,   0,   1, 128,
      0,   0,   1, 128,   0,  34, 137, 162,
    216,  42, 169, 182, 136,  34, 137, 128,
      0,   0,   1, 128,   0,   0,   1, 170,
    170, 144,  15,  85,  85, 128,   0,   0,
      1, 128,   0,   0,   1, 128,   0, 114,
     19, 138,  18,  51, 159, 194,  82,  59,
    141, 128,   0,   0,   1, 128,   0,   0,
      1, 170, 170, 144,  15,  85,  85, 128,
      0,   0,   1, 128,   0,   0,   1, 128,
      0, 122,  19, 194,  18, 123, 159, 194,
     82, 123, 141, 128,   0,   0,   1, 128,
      0,   0,   1, 170, 170, 144,  15,  85,
     85, 128,   0,   0,   1, 128,   0,   0,
      1, 128,   0, 113, 157, 138,  66,  50,
     77, 194,  80,  57, 143, 128,   0,   0,
      1, 128,   0,   0,   1, 170, 170, 144,
     15,  85,  85, 128,   0,   0,   1, 128,
      0,   0,   1, 128,   0,  99, 155, 148,
    162,  37, 163, 196,  34,  51, 155, 128,
      0,   0,   1, 128,   0,   0,   1, 170,
    170, 144,  15,  85,  85, 128,   0,   0,
      1, 128,   0,   0,   1, 128,   0, 113,
    221, 138,   8,  50,   9, 194,   8,  57,
    221, 128,   0,   0,   1, 128,   0,   0,
      1, 170, 170, 144,  15,  85,  85, 128,
      0,   0,   1, 128,   0,   0,   1, 128,
      0,  59, 157, 192,  72,  65, 137, 194,
      8,  57, 221, 128,   0,   0,   1, 128,
      0,   0,   1, 170, 170, 144,  15,  85,
     85, 128,   0,   0,   1, 128,   0,   0,
      1, 128,   0,  28,  33, 130,  32,  12,
     33, 144,  32,  14, 249, 128,   0,   0,
      1, 128,   0,   0,   1, 170, 170, 144,
     15,  85,  85, 128,   0,   0,   1, 128,
      0,   0,   1, 128,   0,  51, 143, 200,
     80,  73, 145, 202,  16,  49, 207, 128,
      0,   0,   1, 128,   0,   0,   1, 170,
    170, 144,  15,  85,  85, 128,   0,   0,
      1, 128,   0,   0,   1, 128,   0,  16,
    137, 144, 136,  28, 169, 146, 216,  28,
    137, 128,   0,   0,   1, 128,   0,   0,
      1, 170, 170, 144,  15,  85,  85, 128,
      0,   0,   1, 128,   0,   0,   1, 128,
      0,  74,  15, 202,  16, 123, 145, 202,
     80,  51, 143, 128,   0,   0,   1, 128,
      0,   0,   1, 170, 170,   4,  65,  41,
    128, 128, 128, 128, 128, 128, 128,   0,
    128, 128,  71,  41,  16,  16, 124, 146,
    144, 144, 146, 124,  16,  16,  71,  41,
    194, 124,  32,  32,  32, 248,  32,  32,
     32,  28,  70,  55, 132, 120,  72, 132,
    132,  72, 120, 132,  71,  41,  16,  16,
     16, 254,  16, 254,  16,  40,  68, 130,
     65,  41, 128, 128, 128, 128,   0,   0,
    128, 128, 128, 128,  70,  41, 120, 132,
      4, 120, 132, 132, 120, 128, 132, 120,
     68, 225, 144, 144,  72,  41,  60,  66,
    153, 165, 161, 161, 165, 153,  66,  60,
     69, 118, 248,   0, 120, 136, 120,   8,
    112,  70,  40,  36,  36,  72,  72, 144,
     72,  72,  36,  36,  70,  35,   4,   4,
      4, 252, 144,  15,  85,  85, 128,   0,
      0,   1, 128,   0,   3, 193, 128,   0,
      0,   1, 128,   0, 114,  73, 138,  72,
     51, 201, 194,  84,  58,  99, 128,   0,
      0,   1, 170, 170,  72,  41,  60,  66,
    165, 169, 185, 165, 165, 185,  66,  60,
     70, 208, 252,  67, 195,  64, 160, 160,
     64,  71,  56, 254,   0,  16,  16,  16,
    254,  16,  16,  16,  69, 118, 248, 128,
    128, 112,   8, 136, 112,  69, 118, 112,
    136,   8, 112,   8, 136, 112,  67, 194,
    128,  64,  32,  72,   9, 128,  64,  89,
    102,  66,  66,  66,  66,  66,  66,  70,
     27,  28,  20,  20,  20,  20,  20, 116,
    244, 244, 244, 244, 124,  66,  97, 192,
    192,  67,   1, 192,  32,  67, 118,  32,
     32,  32,  32, 160,  96,  32,  69, 118,
    248,   0, 112, 136, 136, 136, 112,  70,
     40, 144, 144,  72,  72,  36,  72,  72,
    144, 144,  70,  41, 132, 156,  84,  44,
     36,  80,  80,  72, 196,  68,  70,  41,
    156, 136,  68,  52,  40,  80,  80,  72,
    196,  68,  70,  41, 132, 156,  84,  44,
     36, 208,  48,  72,  36, 196,  70,  41,
    120, 132, 132, 132,  96,  16,  16,   0,
     16,  16,  70,  45, 132, 132, 132, 132,
    252, 132, 132,  72,  72,  48,   0,   0,
     24,  96,  70,  45, 132, 132, 132, 132,
    252, 132, 132,  72,  72,  48,   0,   0,
     96,  24,  70,  45, 132, 132, 132, 132,
    252, 132, 132,  72,  72,  48,   0,   0,
     72,  48,  70,  45, 132, 132, 132, 132,
    252, 132, 132,  72,  72,  48,   0,   0,
    152, 100,  70,  45, 132, 132, 132, 132,
    252, 132, 132,  72,  72,  48,   0,   0,
     72,  72,  70,  45, 132, 132, 132, 132,
    252, 132, 132,  72,  72,  48,   0,  48,
     72,  48,  71,  41, 158, 144, 144, 144,
    144, 254, 144, 144,  80,  62,  70,  11,
     96,  16, 120, 132, 132, 128, 128, 128,
    128, 132, 132, 120,  70,  45, 252, 128,
    128, 128, 128, 248, 128, 128, 128, 252,
      0,   0,  24,  96,  70,  45, 252, 128,
    128, 128, 128, 248, 128, 128, 128, 252,
      0,   0,  96,  24,  70,  45, 252, 128,
    128, 128, 128, 248, 128, 128, 128, 252,
      0,   0,  72,  48,  70,  45, 252, 128,
    128, 128, 128, 248, 128, 128, 128, 252,
      0,   0,  72,  72,  69,  45, 248,  32,
     32,  32,  32,  32,  32,  32,  32, 248,
      0,   0,  24,  96,  69,  45, 248,  32,
     32,  32,  32,  32,  32,  32,  32, 248,
      0,   0, 192,  48,  69,  45, 248,  32,
     32,  32,  32,  32,  32,  32,  32, 248,
      0,   0, 144,  96,  69,  45, 248,  32,
     32,  32,  32,  32,  32,  32,  32, 248,
      0,   0, 144, 144,  71,  41, 120,  68,
     66,  66,  66, 242,  66,  66,  68, 120,
     70,  45, 132, 140, 140, 148, 148, 164,
    164, 196, 196, 132,   0,   0, 152, 100,
     70,  45, 120, 132, 132, 132, 132, 132,
    132, 132, 132, 120,   0,   0,  24,  96,
     70,  45, 120, 132, 132, 132, 132, 132,
    132, 132, 132, 120,   0,   0,  96,  24,
     70,  45, 120, 132, 132, 132, 132, 132,
    132, 132, 132, 120,   0,   0,  72,  48,
     70,  45, 120, 132, 132, 132, 132, 132,
    132, 132, 132, 120,   0,   0, 152, 100,
     70,  45, 120, 132, 132, 132, 132, 132,
    132, 132, 132, 120,   0,   0,  72,  72,
     70,  68, 132,  72,  48,  72, 132,  70,
     27, 128, 184,  68, 196, 164, 164, 148,
    148, 140, 136, 116,   4,  70,  45, 120,
    132, 132, 132, 132, 132, 132, 132, 132,
    132,   0,   0,  24,  96,  70,  45, 120,
    132, 132, 132, 132, 132, 132, 132, 132,
    132,   0,   0,  96,  24,  70,  45, 120,
    132, 132, 132, 132, 132, 132, 132, 132,
    132,   0,   0,  72,  48,  70,  45, 120,
    132, 132, 132, 132, 132, 132, 132, 132,
    132,   0,   0,  72,  72,  71,  45,  16,
     16,  16,  16,  16,  40,  68,  68, 130,
    130,   0,   0,  96,  24,  70,  42, 128,
    128, 128, 240, 136, 132, 132, 136, 240,
    128, 128,  70,  41, 152, 164, 132, 132,
    136, 176, 144, 136, 136, 112,  70,  43,
    116, 140, 132, 132, 124,   4, 132, 120,
      0,   0,  24,  96,  70,  43, 116, 140,
    132, 132, 124,   4, 132, 120,   0,   0,
     96,  24,  70,  43, 116, 140, 132, 132,
    124,   4, 132, 120,   0,   0,  72,  48,
     70,  43, 116, 140, 132, 132, 124,   4,
    132, 120,   0,   0, 152, 100,  70,  43,
    116, 140, 132, 132, 124,   4, 132, 120,
      0,   0,  72,  72,  70,  44, 116, 140,
    132, 132, 124,   4, 132, 120,   0,   0,
     48,  72,  48,  71,  39, 124, 146, 144,
    144, 126,  18, 146, 124,  70,   9,  96,
     16, 120, 132, 128, 128, 128, 128, 132,
    120,  70,  43, 120, 132, 128, 128, 252,
    132, 132, 120,   0,   0,  24,  96,  70,
     43, 120, 132, 128, 128, 252, 132, 132,
    120,   0,   0,  96,  24,  70,  43, 120,
    132, 128, 128, 252, 132, 132, 120,   0,
      0,  72,  48,  70,  43, 120, 132, 128,
    128, 252, 132, 132, 120,   0,   0,  72,
     72,  69,  43, 248,  32,  32,  32,  32,
     32,  32,  96,   0,   0,  48, 192,  69,
     43, 248,  32,  32,  32,  32,  32,  32,
     96,   0,   0, 192,  48,  69,  43, 248,
     32,  32,  32,  32,  32,  32,  96,   0,
      0, 144,  96,  69,  43, 248,  32,  32,
     32,  32,  32,  32,  96,   0,   0, 144,
    144,  70,  43, 120, 132, 132, 132, 132,
    132, 124,   4,  68,  40,  24, 100,  70,
     43, 132, 132, 132, 132, 132, 132, 196,
    184,   0,   0, 152, 100,  70,  43, 120,
    132, 132, 132, 132, 132, 132, 120,   0,
      0,  24,  96,  70,  43, 120, 132, 132,
    132, 132, 132, 132, 120,   0,   0,  96,
     24,  70,  43, 120, 132, 132, 132, 132,
    132, 132, 120,   0,   0,  72,  48,  70,
     43, 120, 132, 132, 132, 132, 132, 132,
    120,   0,   0, 152, 100,  70,  43, 120,
    132, 132, 132, 132, 132, 132, 120,   0,
      0,  72,  72,  70,  54,  48,   0,   0,
    252,   0,   0,  48,  70,  25, 128, 120,
    196, 164, 164, 148, 148, 140, 120,   4,
     70,  43, 116, 140, 132, 132, 132, 132,
    132, 132,   0,   0,  24,  96,  70,  43,
    116, 140, 132, 132, 132, 132, 132, 132,
      0,   0,  96,  24,  70,  43, 116, 140,
    132, 132, 132, 132, 132, 132,   0,   0,
     72,  48,  70,  43, 116, 140, 132, 132,
    132, 132, 132, 132,   0,   0,  72,  72,
     70,  13, 120,   4,   4,  52,  76, 132,
    132, 132, 132, 132,   0,   0,  96,  24,
     69,  11, 128, 128, 128, 192, 160, 144,
    136, 136, 136, 240, 128, 128,  70,  13,
    120,   4,   4,  52,  76, 132, 132, 132,
    132, 132,   0,   0,  72,  72,
};
